@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
- Copyright (C) 2008-2011 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+ Copyright (C) 2008-2012 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 from PyQt4.QtCore import Qt, QString, QRectF, QPointF, QSizeF, QSize, pyqtProperty, QObject
 from PyQt4.QtGui import QGraphicsItem, QPixmap, QPainter
 from PyQt4.QtGui import QColor
-from util import logException, isAlive
-from common import LIGHTSOURCES, ZValues, InternalParameters, PREF
+from util import logException, isAlive, stack, logDebug
+from common import LIGHTSOURCES, ZValues, InternalParameters, PREF, Debug
 
 def chiNext(element, offset):
     """the element name of the following value"""
@@ -30,12 +30,6 @@ def chiNext(element, offset):
     baseValue = int(baseValue)
     return '%s%d' % (color, baseValue+offset)
 
-def offsetTiles(tileName, offsets):
-    """returns two adjacent tiles placed at offsets"""
-    chow2 = chiNext(tileName, offsets[0])
-    chow3 = chiNext(tileName, offsets[1])
-    return [chow2, chow3]
-
 def swapTitle(element):
     """if istitle, return lower. If lower, return capitalize"""
     if element.islower():
@@ -56,14 +50,14 @@ class GraphicsTileItem(QGraphicsItem):
 
     def setClippingFlags(self):
         """if we do not show shadows, we need to clip"""
-        # TODO: rethink propagation of PREF.showShadows
         showShadows = self.showShadows
         self.setFlag(QGraphicsItem.ItemClipsChildrenToShape, enabled=not showShadows)
         self.setFlag(QGraphicsItem.ItemClipsToShape, enabled=not showShadows)
 
     def keyPressEvent(self, event):
         """redirect to the board"""
-        assert self == self.tile.board.focusTile.graphics
+        assert self == self.tile.board.focusTile.graphics, 'id(self):%s, self:%s, focusTile:%s/%s' % \
+           (id(self), self, id(self.tile.board.focusTile), self.tile.board.focusTile)
         return self.tile.board.keyPressEvent(event)
 
     def __lightDistance(self):
@@ -257,7 +251,7 @@ class Tile(QObject):
         self.__xoffset = xoffset
         self.__yoffset = yoffset
         self.__element = element
-        self.dark = False
+        self.__dark = False
         self.level = level
         self.activeAnimation = dict() # key is the property name
         self.queuedAnimations = []
@@ -332,6 +326,9 @@ class Tile(QObject):
         def fset(self, value):
             assert self.graphics or value
             if self.graphics:
+                if self.element in Debug.focusable:
+                    newStr = 'focusable' if value else 'unfocusable'
+                    logDebug('%s: %s from %s' % (newStr, self.element, stack('')[-2]))
                 self.graphics.setFlag(QGraphicsItem.ItemIsFocusable, value)
         return property(**locals())
 
@@ -384,6 +381,20 @@ class Tile(QObject):
                     self.graphics.update()
         return property(**locals())
 
+    @apply
+    def dark(): # pylint: disable=E0202
+        """show face?"""
+        def fget(self):
+            # pylint: disable=W0212
+            return self.__dark
+        def fset(self, value):
+            # pylint: disable=W0212
+            if value != self.__dark:
+                self.__dark = value
+                if self.graphics:
+                    self.graphics.update()
+        return property(**locals())
+
     def setBoard(self, board, xoffset=None, yoffset=None, level=None):
         """change Position of tile in board"""
         placeDirty = False
