@@ -18,7 +18,6 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from util import m18nc
 from common import InternalParameters, PREF, ZValues
 from PyQt4.QtCore import QRectF, QPointF
 from PyQt4.QtGui import QGraphicsSimpleTextItem
@@ -251,10 +250,10 @@ class UIWall(Wall):
         sideCenter = side.center()
         name = side.nameLabel
         if player.handBoard:
-            player.handContent = player.computeHand()
-            name.setText(' - '.join([m18nc('kajongg', player.name), unicode(player.handContent.total())]))
+            player.newHandContent = player.computeNewHand()
+            name.setText(' - '.join([player.localName, unicode(player.newHandContent.total())]))
         else:
-            name.setText(m18nc('kajongg', player.name))
+            name.setText(player.localName)
         name.resetTransform()
         if side.rotation() == 180:
             rotateCenter(name, 180)
