@@ -20,6 +20,7 @@
 #define SUDOKUBOARD_H
 
 #include "globals.h"
+#include "skgraph.h"
 
 #include <QObject>
 #include <QList>
@@ -35,6 +36,7 @@ typedef MoveList     GuessesList;
 
 enum                 GuessingMode {Random, NotRandom};
 
+class SKGraph;
 class State;
 
 /**
@@ -57,8 +59,8 @@ class State;
  * zero if it is a given (or clue) or has been (tentatively) solved.
  *
  * The central method of the class is the solver (solve()). It is used when
- * solving an existing puzzle, generating a puzzle, checking the validity of a
- * puzzle keyed in or loaded from a file, verifying that a puzzle is solvable,
+ * solving an existing puzzle, generating a new puzzle, checking the validity of
+ * a puzzle keyed in or loaded from a file, verifying that a puzzle is solvable,
  * checking that it has only one solution and collecting statistics related to
  * the difficulty of solving the puzzle.
  *
@@ -79,19 +81,18 @@ class State;
  * The principal methods used in puzzle-generation are generatePuzzle(),
  * insertValues(), removeValues() and checkPuzzle().  The checkPuzzle() method
  * is also used to check the validity of a puzzle entered manually or loaded
- * from a file.
+ * from a file.  The virtual methods clear() and fillBoard() clear a board or
+ * fill it with randomly chosen values (the solution).
  *
- * The pure virtual methods setUpBoard(), clear(), fillBoard(), makeBlockIndex()
- * and makeRowColIndex(), as implemented by descendant classes, set up a
- * board of the required size and layout, clear a board, fill a board with
- * randomly chosen values (the solution) and make indices (lists of cells) for
- * all the groups in that type and size of puzzle.  The setUpBoard() method
- * should be called just once for each SudokuBoard descendant object,
- * immediately after constructing that object.
+ * The main input to the puzzle generator/solver is a pointer to an object of
+ * type SKGraph.  That object contains the shape, dimensions and rules for
+ * grouping the cells of the particular type of Sudoku being played, including
+ * Classic Sudoku in several sizes and variants, Samurai Sudoku with five
+ * overlapping grids and the three-dimensional Roxdoku in several sizes.
  *
- * Each group (row, column or block) contains N cells in which the numbers
- * 1 to N must appear exactly once.  In the SudokuBoard class, N can be 4, 9,
- * 16 or 25, but the descendant objects do not all support all four sizes.
+ * Each group (row, column, blocki or plane) contains N cells in which the
+ * numbers 1 to N must appear exactly once.  N can be 4, 9, 16 or 25, but not
+ * all types of puzzle support all four sizes.
  *
  * As examples, a classic Sudoku puzzle has 27 groups: 9 rows, 9 columns and
  * 9 blocks of 3x3 cells.  Each group must contain the numbers 1 to 9 once and
@@ -100,10 +101,12 @@ class State;
  * columns, 45 rows and 41 blocks of 3x3 cells, making 131 groups in all.  A
  * classic Sudoku puzzle of size 16 has 16 rows, 16 columns and 16 blocks of
  * 4x4 cells, making 48 groups, where each group must contain the values 1 to
- * 16 once and only once.  That range of values is usually displayed and entered
- * as letters of the Roman alphabet, but that is the concern of View classes.
+ * 16 once and only once.  A 3x3x3 Roxdoku puzzle is a cube with 9 groups of
+ * 3x3 cells.  These form 3 planes perpendicular to each of the X, Y and Z axes.
  *
- * SudokuBoard and its inheritors are Model classes.
+ * All these configurations are represented by a table of groups (or cliques) in
+ * the SKGraph object, which maps cell numbers into groups.  The SudokuBoard
+ * class itself is unaware of the type of puzzle it is generating or solving.
  */
 class SudokuBoard : public QObject
 {
@@ -112,18 +115,11 @@ public:
     /**
      * Construct a new SudokuBoard object with a required type and size.
      *
-     * @param parent        A pointer to the object that owns the SudokuBoard
-     *                      object and will delete it automatically.
-     * @param sudokuType    The type of Sudoku board required (defined
-     *                      in file globals.h).
-     * @param blockSize     The size of blocks required (value 2 to 5).  The
-     *                      board will have blocks, rows and columns with
-     *                      blockSize squared cells and the numbers to be
-     *                      filled in will range from 1 to blockSize squared
-     *                      (e.g. a classic Sudoku has blockSize = 3 and there
-     *                      are 3x3 = 9 cells in each row, column and block).
+     * @param graph         The layout, type and size of the board, including
+     *                      the grouping of cells into rows, columns and blocks,
+     *                      as required by the type of puzzle being played.
      */
-    SudokuBoard (QObject * parent, SudokuType sudokuType, int blockSize); 
+    SudokuBoard (SKGraph * graph);
 
     /**
      * Generate a puzzle and its solution (see details in the class-header doc).
@@ -139,13 +135,6 @@ public:
                                             Difficulty      difficulty,
                                             Symmetry        symmetry);
 
-    /**
-     * Convert puzzle values from KSudoku format to SudokuBoard format.
-     * SudokuBoard stores by column within row and sets unused cells = -1.
-     * KSudoku stores values by row within column and sets unused cells = 0.
-    */
-    BoardContents & fromKSudoku (const QByteArray & values);
-
     /**
      * Check that a puzzle is soluble, has the desired solution and has only one
      * solution.  This method can be used to check puzzles loaded from a file or
@@ -206,35 +195,11 @@ public:
     BoardContents &         solveBoard (const BoardContents & boardValues,
                                               GuessingMode gMode = Random);
 
-    /**
-     * Return the number of cells in the board.
-     */
-    int                     area() {return m_boardArea;};
-
-    /**
-     * Return the number of cells along the side of the board.
-     */
-    int                     boardSize() {return m_boardSize;};
-
-    /**
-     * Set up an empty board with the required number of cells and make indices
-     * to the required groups of cells, e.g. rows, columns and blocks (pure
-     * virtual).  The indices make it possible for one solver to handle many
-     * types and sizes of Sudoku puzzle.  See the class description for an
-     * overview.
-     */
-    virtual void            setUpBoard() = 0;
-
     /**
      * Initialize or re-initialize the random number generator.
      */
     void                    setSeed();
 
-    /**
-     * Clear a board-vector of the required type and size (pure virtual).
-     */
-    virtual void            clear (BoardContents & boardValues) = 0;
-
     /**
      * Format some board-contents with ruled lines and boxes and send them to
      * the default printer.  Uses Qt's QPrinter and QPainter classes.
@@ -243,14 +208,6 @@ public:
      */
     void                    sendToPrinter (const BoardContents & boardValues);
 
-    /**
-     * Format some board-contents into text for printing, debugging output or
-     * saving to a file that can be loaded.
-     *
-     * @param boardValues   The contents of the board to be formatted.
-     */
-    void                    print (const BoardContents & boardValues);
-
 protected:
     BoardContents           m_currentValues;	///< The current state of the
 						///< cell values during solve().
@@ -263,8 +220,6 @@ protected:
     int                     m_blockSize;	///< The number of cells on one
 						///< side of a square block (2,
 						///< 3, 4 or 5).
-    int                     m_gridArea;		///< The number of cells in a
-						///< square grid (e.g. 81).
     int                     m_boardSize;	///< The number of cells on one
 						///< side of the whole board.
 						///< In Samurai with 9x9 grids,
@@ -275,24 +230,11 @@ protected:
     int                     m_overlap;		///< The degree of overlap in a
 						///< Samurai board (=m_blockSize
 						///< or 1 for a TinySamurai).
-
-    int                     m_fillStartRow;	///< The row where fillBoard()
-						///< finds the first block to
-						///< fill.
-    int                     m_fillStartCol;	///< The column where
-						///< fillBoard() finds the
-						///< first block to fill.
     int                     m_nGroups;		///< The total number of rows,
 						///< columns, blocks, diagonals,
 						///< etc. in the puzzle.
     int                     m_groupSize;	///< The number of cells in each
 						///< group (= m_order).
-    QVector<int>            m_groupList;	///< An index from groups to the
-						///< cells they contain.  Each
-						///< cell will be in three
-						///< groups, a row, a column and
-						///< a block, and in some types
-						///< of puzzle maybe more.
     QVector<int>            m_cellIndex;	///< A first-level index from a
 						///< cell to the list of groups
 						///< to which it belongs.
@@ -300,36 +242,20 @@ protected:
 						///< cells to individual groups
 						///< to which they belong.
 
+    /**
+     * Clear a board-vector of the required type and size (virtual).
+     *
+     * @param boardValues   The board-contents to be cleared.
+     */
+    virtual void            clear (BoardContents & boardValues);
+
     /**
      * Fill the board with randomly chosen valid values, thus generating a
-     * solution from which a puzzle can be created (pure virtual).
+     * solution from which a puzzle can be created (virtual).
      *
      * @return              The filled board-vector.
      */
-    virtual BoardContents & fillBoard() = 0;
-
-    /**
-     * Make a list of cells in rows and columns of the board (pure virtual).
-     * The rows and columns indexed form a square of cells with blockSize
-     * squared rows and the same number of columns.
-     *
-     * @param i             The row-number in the board of the top left cell.
-     * @param j             The column-number in the board of the top left cell.
-     * @param index         The current position in the list of groups.
-     * @return              The updated position in the list of groups.
-     */
-    virtual qint32          makeRowColIndex (int i, int j, qint32 index) = 0;
-
-    /**
-     * Make a list of cells in blocks of the board (pure virtual).  In a classic
-     * Sudoku a block is a small square of cells of size blockSize * blockSize,
-     * but in other types of puzzle it can have other shapes or connections
-     * between cells (e.g. as in XSudoku, Jigsaw or Roxdoku types).
-     *
-     * @param index         The current position in the list of groups.
-     * @return              The updated position in the list of groups.
-     */
-    virtual qint32          makeBlockIndex (qint32 index) = 0;
+    virtual BoardContents & fillBoard();
 
     /*
      * Fill a vector of integers with values from 1 up to the size of the
@@ -339,14 +265,8 @@ protected:
      */
     void                    randomSequence (QVector<int> & sequence);
 
-    // Helper methods for inheriting classes.
-    void                    indexCellsToGroups();
-    qint32                  indexSquareBlock (qint32 index, int topLeft);
-
-    void                    markUnusable (BoardContents & boardValues,
-                                    int imin, int imax, int jmin, int jmax);
-
 private:
+    SKGraph *               m_graph;
     int                     m_vacant;
     int                     m_unusable;
     enum                    MoveType {Single, Spot, Guess, Wrong,
@@ -485,6 +405,14 @@ private:
     int                     getSymmetricIndices (int size, Symmetry type,
                                                  int cell, int * out);
 
+    /**
+     * Format some board-contents into text for printing, debugging output or
+     * saving to a file that can be loaded.
+     *
+     * @param boardValues   The contents of the board to be formatted.
+     */
+    void                    print (const BoardContents & boardValues);
+
     // Methods for packing two small integers into one and unpacking them.  Used
     // for speed and efficiency in the solver and other places.
     inline Pair             setPair (int p, int v ) { return (p << 8) + v; }
